"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.XmlTemplateHelper = void 0;
const xml_helper_1 = require("./xml-helper");
class XmlTemplateHelper {
    constructor(archive) {
        this.relType = 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/slide';
        this.archive = archive;
        this.path = 'ppt/_rels/presentation.xml.rels';
    }
    getCreationIds() {
        return __awaiter(this, void 0, void 0, function* () {
            const archive = yield this.archive;
            const relationships = yield xml_helper_1.XmlHelper.getTargetsByRelationshipType(archive, this.path, this.relType);
            const creationIds = [];
            for (const slideRel of relationships) {
                const slideXml = yield xml_helper_1.XmlHelper.getXmlFromArchive(archive, 'ppt/' + slideRel.file);
                const creationIdSlide = slideXml
                    .getElementsByTagName('p14:creationId')
                    .item(0)
                    .getAttribute('val');
                const elementIds = this.elementCreationIds(slideXml, archive);
                creationIds.push({
                    id: Number(creationIdSlide),
                    number: this.parseSlideRelFile(slideRel.file),
                    elements: elementIds
                });
            }
            return creationIds;
        });
    }
    parseSlideRelFile(slideRelFile) {
        return Number(slideRelFile
            .replace('slides/slide', '')
            .replace('.xml', ''));
    }
    elementCreationIds(slideXml, archive) {
        const slideElements = slideXml
            .getElementsByTagName('p:cNvPr');
        const elementIds = [];
        for (const item in slideElements) {
            const slideElement = slideElements[item];
            if (slideElement.getAttribute !== undefined) {
                const creationIdElement = slideElement
                    .getElementsByTagName('a16:creationId');
                if (creationIdElement.item(0)) {
                    elementIds.push(this.getElementInfo(slideElement, archive));
                }
            }
        }
        return elementIds;
    }
    getElementInfo(slideElement, archive) {
        const elementName = slideElement.getAttribute('name');
        let type = slideElement.parentNode.parentNode.tagName;
        const creationId = slideElement
            .getElementsByTagName('a16:creationId')
            .item(0)
            .getAttribute('id');
        const mapUriType = {
            'http://schemas.openxmlformats.org/drawingml/2006/table': 'table',
            'http://schemas.openxmlformats.org/drawingml/2006/chart': 'chart'
        };
        type = type.replace('p:', '');
        switch (type) {
            case 'graphicFrame':
                const graphicData = slideElement.parentNode.parentNode.getElementsByTagName('a:graphicData')[0];
                const uri = graphicData.getAttribute('uri');
                type = (mapUriType[uri]) ? mapUriType[uri] : type;
                break;
        }
        switch (type) {
            case 'chart':
                // const slideXml = await XmlHelper.getXmlFromArchive(
                //   archive,
                //   'ppt/' + slideRel.file
                // )
                // XmlHelper.dump(slideElement.parentNode.parentNode)
                break;
        }
        return {
            name: elementName,
            type: type,
            id: creationId
        };
    }
}
exports.XmlTemplateHelper = XmlTemplateHelper;
//# sourceMappingURL=xml-template-helper.js.map